| Home | Libraries | People | FAQ | More

# Chapter 2. Floating Point Utilities

Table of Contents

Rounding Truncation and Integer Conversion
  Rounding Functions
  Truncation Functions
  Integer and Fractional Part Splitting (modf)
Floating-Point Classification: Infinities and NaNs
Sign Manipulation Functions
Facets for Floating-Point Infinities and NaNs
  Introduction
  Reference
  Examples
  Portability
  Design Rationale
Floating-Point Representation Distance (ULP), and Finding Adjacent Floating-Point Values
  Finding the Next Representable Value in a Specific Direction (nextafter)
  Finding the Next Greater Representable Value (float_next)
  Finding the Next Smaller Representable Value (float_prior)
  Calculating the Representation Distance Between Two floating-point Values (ULP) float_distance
  Advancing a floating-point Value by a Specific Representation Distance (ULP) float_advance
  Obtaining the Size of a Unit In the Last Place - ULP
Floating-point Comparison
Condition Numbers
ULPs Plots

Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)